### Name: mafc
### Title: Links for Binomial Family for m-alternative Forced-choice
### Aliases: mafc mafc.logit mafc.probit
### Keywords: models

### ** Examples

#A toy example,
b <- log(3.5)
g <- 1/3
d <- 0.0
a <- 0.04
p <- c(a, b, g, d)
num.tr <- 160
cnt <- 10^seq(-2, -1, length = 6) # contrast levels

#simulated observer responses
wb <- function(p) {
                   p[3] + (1 - p[3] - p[4]) *
                        (1 - exp(-((cnt/p[1])^exp(p[2]))))
                   }
ny <- rbinom(length(cnt), num.tr, wb(p))
nn <- num.tr - ny
phat <- ny/(ny + nn)
resp.mat <- matrix(c(ny, nn), ncol = 2)

ddprob.glm <- glm(resp.mat ~ cnt, family = binomial(mafc.probit(3)))
ddlog.glm <- glm(resp.mat ~ cnt, family = binomial(mafc.logit(3)))

plot(cnt, phat, log = "x", cex = 1.5, ylim = c(0, 1))
pcnt <- seq(0.01, 0.1, len = 100)
lines(pcnt, predict(ddprob.glm, data.frame(cnt = pcnt),
                        type = "response"), lwd = 2)
lines(pcnt, predict(ddlog.glm, data.frame(cnt = pcnt),
                        type = "response"), lwd = 2, lty = 2)

#More interesting example with data from Yssaad-Fesselier and Knoblauch
data(ecc2)
ecc2.glm <- glm(cbind(nyes, nno) ~ Contr * Size * task, 
                        family = binomial(mafc.probit(4)), data = ecc2)
summary(ecc2.glm)
ecc2$fit <- fitted(ecc2.glm)
library(lattice)
xyplot(nyes/(nyes + nno) ~ Contr | Size * task, data = ecc2,
        subscripts = TRUE, ID = with(ecc2, Size + as.numeric(task)),
        scale = list(x = list(log = TRUE), 
                                 y = list(limits = c(0, 1.05))),
        xlab = "Contrast", ylab = "Proportion Correct Response",
        panel = function(x, y, subscripts, ID, ...) {
                which = unique(ID[subscripts])
                llines(x, ecc2$fit[which ==ID], col = "black", ...)
                panel.xyplot(x, y, pch = 16, ...)
                panel.abline(h = 0.25, lty = 2, ...)
                }
)




